Origin
------

.. autosimple:: swh.web.api.views.origin.api_origins

.. autosimple:: swh.web.api.views.origin.api_origin

.. autosimple:: swh.web.api.views.origin.api_origin_search

.. autosimple:: swh.web.api.views.origin.api_origin_visits

.. autosimple:: swh.web.api.views.origin.api_origin_visit

.. autosimple:: swh.web.api.views.origin.api_origin_visit_latest

.. autosimple:: swh.web.api.views.origin.api_origin_metadata_search

.. autosimple:: swh.web.api.views.origin.api_origin_intrinsic_metadata

.. autosimple:: swh.web.api.views.origin.api_origin_extrinsic_metadata
